@@ -3,7 +3,13 @@ from python_framework import Controller, ControllerMethod, HttpStatus
 from enumeration.AccessDomain import AccessDomain
 
 
-@Controller(url = '/memory', tag='Memory', description='Memory controller')
+@Controller(
+    url = '/memory',
+    tag = 'Memory',
+    description = 'Memory controller'
+    # , logRequest = True
+    # , logResponse = True
+)
 class MemoryController:
 
     @ControllerMethod(url = '/',
@@ -11,8 +17,6 @@ class MemoryController:
         # requestClass = [MessageDto.MessageRequestDto]
         # responseClass = [MessageDto.MessageResponseDto]
         # responseClass = [MessageDto.MessageRequestDto]
-        # , logRequest = True
-        # , logResponse = True
     )
     def get(self):
         return self.service.memory.findAll(), HttpStatus.OK
